@@ -189,3 +189,10 @@ void CleaN900::on_pushDet_clicked()
     process.start("sh signal.sh");
     process.waitForFinished();
 }
+
+void CleaN900::on_pushDpkgPurge_clicked()
+{
+    QProcess process;
+    process.start("sh purgedpkg.sh");
+    process.waitForFinished();
+}
